@@ -8,6 +8,8 @@
 
 #include <iostream>
 
+#include <cstdlib>
+
 static const bool debug_flag = false;
 
 namespace Atlas { namespace Codecs {
@@ -436,53 +438,56 @@ void Bach::poll(bool can_read)
 {
     if (!can_read) return;
 
-    do
-    {
-	int next = m_socket.get();
+    m_socket.peek();
 
-	if (next == std::iostream::traits_type::eof()) {
-	    return;
-	}
-        // check for comment character here, so we don't have
-        // to do it in every section
+    std::streamsize count;
 
-        switch(next)
-        {
-        case '#':
-            if(!stringmode())
+    if ((count = m_socket.rdbuf()->in_avail()) > 0) {
+
+        for (int i = 0; i < count; ++i) {
+
+	    int next = m_socket.rdbuf()->sbumpc();
+
+            // check for comment character here, so we don't have
+            // to do it in every section
+
+            switch(next)
             {
-                m_state.push(PARSE_COMMENT);
+            case '#':
+                if(!stringmode())
+                {
+                    m_state.push(PARSE_COMMENT);
+                    continue;
+                }
+                break;
+
+            case '\n':
+	        m_linenum++;
+                if(!stringmode())
+                    continue;
+                break;
+            case '\r': // dealing with DOS files, I guess
                 continue;
+            default:
+                break;
             }
-            break;
 
-        case '\n':
-	    m_linenum++;
-            if(!stringmode())
-                continue;
-            break;
-        case '\r': // dealing with DOS files, I guess
-            continue;
-        default:
-            break;
+            switch (m_state.top())
+	    {
+            case PARSE_INIT:       parseInit(next); break;
+            case PARSE_STREAM:     parseStream(next); break;
+            case PARSE_MAP:        parseMap(next); break;
+            case PARSE_LIST:       parseList(next); break;
+            case PARSE_DATA:       parseData(next); break;
+            case PARSE_INT:	       parseInt(next); break;
+            case PARSE_FLOAT:      parseFloat(next); break;
+            case PARSE_STRING:     parseString(next); break;
+	    case PARSE_LITERAL:    parseLiteral(next); break;
+            case PARSE_NAME:       parseName(next); break;
+	    case PARSE_COMMENT:    parseComment(next); break;
+	    }
         }
-
-        switch (m_state.top())
-	{
-        case PARSE_INIT:       parseInit(next); break;
-        case PARSE_STREAM:     parseStream(next); break;
-        case PARSE_MAP:        parseMap(next); break;
-        case PARSE_LIST:       parseList(next); break;
-        case PARSE_DATA:       parseData(next); break;
-        case PARSE_INT:	       parseInt(next); break;
-        case PARSE_FLOAT:      parseFloat(next); break;
-        case PARSE_STRING:     parseString(next); break;
-	case PARSE_LITERAL:    parseLiteral(next); break;
-        case PARSE_NAME:       parseName(next); break;
-	case PARSE_COMMENT:    parseComment(next); break;
-	}
     }
-    while (m_socket.rdbuf()->in_avail() > 0);
 }
 
 const std::string Bach::decodeString(const std::string & toDecode)
