@@ -6,6 +6,8 @@
 
 #include <iostream>
 
+#include <cstdlib>
+
 namespace Atlas { namespace Codecs {
     
 XML::XML(std::iostream& s, Atlas::Bridge & b)
@@ -326,23 +328,26 @@ void XML::parseEndTag()
 void XML::poll(bool can_read)
 {
     if (!can_read) return;
-    do
-    {
-	int next = m_socket.get();
 
-	if (next == std::iostream::traits_type::eof()) {
-	    return;
-	}
+    m_socket.peek();
 
-	switch (m_token)
-	{
-	    case TOKEN_TAG:	    tokenTag(next); break;
-	    case TOKEN_START_TAG:   tokenStartTag(next); break;
-	    case TOKEN_END_TAG:	    tokenEndTag(next); break;
-	    case TOKEN_DATA:	    tokenData(next); break;
-	}
+    std::streamsize count;
+
+    while ((count = m_socket.rdbuf()->in_avail()) > 0) {
+
+        for (int i = 0; i < count; ++i) {
+
+	    int next = m_socket.rdbuf()->sbumpc();
+
+	    switch (m_token)
+	    {
+	        case TOKEN_TAG:		    tokenTag(next); break;
+	        case TOKEN_START_TAG:	    tokenStartTag(next); break;
+	        case TOKEN_END_TAG:	    tokenEndTag(next); break;
+	        case TOKEN_DATA:	    tokenData(next); break;
+	    }
+        }
     }
-    while (m_socket.rdbuf()->in_avail() > 0);
 }
 
 void XML::streamBegin()
