@@ -5,11 +5,17 @@
 #ifndef ATLAS_MESSAGE_QUEUEDDECODER_H
 #define ATLAS_MESSAGE_QUEUEDDECODER_H
 
-#include <queue>
 #include <Atlas/Message/DecoderBase.h>
+#include <Atlas/Message/Element.h>
+
+#include <queue>
 
 namespace Atlas { namespace Message {
 
+class Element;
+
+typedef std::map<std::string, Element> MapType;
+
 /** Decoder that presents a queue of Atlas::Message::Element.
  *
  * This message decoder puts arrived objects into a queue and allows the
@@ -30,22 +36,30 @@ public:
     QueuedDecoder();
 
     /// Retrieve the current size of the message queue.    
-    size_t queueSize();
+    size_t queueSize() {
+	return m_objectQueue.size();
+    }
     /// Pop an object from the front of the message queue.
-    Element pop();
+    const MapType popMessage() {
+        MapType r = m_objectQueue.front();
+        m_objectQueue.pop();
+        return r;
+    }
     /// Peek at the object at the front of the queue.
-    Element front();
+    const MapType frontMessage() {
+	return m_objectQueue.front();
+    }
     /// Clear the message queue.
-    void clear();
+    void clearQueue();
     
 protected:
 
     /// This adds a message to the queue.
-    void objectArrived(const Element& obj);
+    void messageArrived(const MapType& obj);
     
 private:
     
-    std::queue<Element> objectQueue;
+    std::queue<MapType> m_objectQueue;
 };
 
 } } // namespace Atlas::Message
