@@ -13,6 +13,15 @@ NoSuchAttrException::~NoSuchAttrException() throw ()
 {
 }
 
+BaseObjectData::BaseObjectData(BaseObjectData *defaults) :
+    m_class_no(BASE_OBJECT_NO), m_refCount(0), m_defaults(defaults),
+    m_attrFlags(0)
+{
+    if(defaults == NULL) {
+        m_attrFlags = -1; //this is default object: all attributes here
+    }
+}
+
 BaseObjectData::~BaseObjectData()
 {
     assert( m_refCount==0 );
